<?php
/*
Plugin Name: Biuro Sections
Description: Biuro Sections plugin
Author: Biuro
Version: 1.0
Author URI: https://www.biuro.lt/
*/


class Biuro_Sections extends WP_Widget {
    // Main constructor
    public function __construct() {
        parent::__construct(
            'biuro-sections',
            __( 'Biuro Sections | Biuro', 'biuro' ),
            array(
                'customize_selective_refresh' => true,
            )
        );
    }

    // The widget form (for the backend )
    public function form( $instance ) {
        // Set widget defaults
        $defaults = array(
            'title'    => '',
            'title1'    => '',
            'description1' => '',
            'content1' => '',
            'title2'    => '',
            'description2' => '',
            'content2' => '',
            'title3'    => '',
            'description3' => '',
            'content3' => '',
            'title4'    => '',
            'description4' => '',
            'content4' => '',
            'title5'    => '',
            'description5' => '',
            'content5' => '',
            'title6'    => '',
            'description6' => '',
            'content6' => '',
            'title7'    => '',
            'description7' => '',
            'content7' => '',
            'title8'    => '',
            'description8' => '',
            'content8' => '',
        );


        // Parse current settings with defaults
        extract( wp_parse_args( ( array ) $instance, $defaults ) ); ?>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Heading', 'biuro' ); ?><?php echo ' ' . $i . ':';  ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( ${'title'} ); ?>" />
        </p>

<?php
        for ($i = 1; $i <= 6; $i++):
?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' . $i ) ); ?>"><?php _e( 'Title', 'biuro' ); ?><?php echo ' ' . $i . ':';  ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' . $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' . $i ) ); ?>" type="text" value="<?php echo esc_attr( ${'title' . $i} ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'description' . $i ) ); ?>"><?php _e( 'Description', 'biuro' ); ?><?php echo ' ' . $i . ':';  ?></label>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'description' . $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'description' . $i ) ); ?>" rows="4"><?php echo wp_kses_post( ${'description' . $i} ); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'content' . $i ) ); ?>"><?php _e( 'Section', 'biuro' ); ?><?php echo ' ' . $i . ':';  ?></label>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'content' . $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'content' . $i ) ); ?>" rows="4"><?php echo wp_kses_post( ${'content' . $i} ); ?></textarea>
        </p>

        <hr>
<?php
        endfor;
 ?>

    <?php }

    // Update widget settings
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;

        $instance['title']    = isset( $new_instance['title'] ) ? wp_strip_all_tags( $new_instance['title'] ) : '';

        for ($i = 1; $i <= 6; $i++):
            $instance['title' . $i]    = isset( $new_instance['title' . $i] ) ? wp_strip_all_tags( $new_instance['title' . $i] ) : '';
            $instance['description' . $i] = isset( $new_instance['description' . $i] ) ? wp_kses_post( $new_instance['description' . $i] ) : '';
            $instance['content' . $i] = isset( $new_instance['content' . $i] ) ? wp_kses_post( $new_instance['content' . $i] ) : '';
        endfor;

        return $instance;
    }

    // Display the widget
    public function widget( $args, $instance ) {
        extract( $args );

        $title = isset( $instance['title'] ) ?$instance['title'] : '';

        for ($i = 1; $i <= 6; $i++):
            ${'title' . $i} = isset( $instance['title' . $i] ) ?$instance['title' . $i] : '';
            ${'description' . $i} = isset( $instance['description' . $i] ) ?$instance['description' . $i] : '';
            ${'content' . $i} = isset( $instance['content' . $i] ) ?$instance['content' . $i] : '';
        endfor;

        // WordPress core before_widget hook (always include )
        echo $before_widget;
        // Display the widget
        echo '<div class="c-sections">';

        if ( $title != "" ) {
            echo '<h2 class="c-sections--heading">' . $title . '</h2>';
        }

        echo '<div class="c-sections--inner">';
        for ($i = 1; $i <= 6; $i++):
            if ( ${'title' . $i} != "" && ${'description' . $i} != ""&& ${'content' . $i} != ""):
                echo '<div class="c-sections--item">';

                    if ( ${'title' . $i} != "" ) {
                        echo '<div class="c-sections--header"><div class="c-sections--ico"><svg width="56px" height="56px"><use xlink:href="#ico--section-' . $i . '"></use></svg></div>' . ${'title' . $i}  . '</div>';
                    }

                    echo '<div class="c-sections--content">';

                    if ( ${'description' . $i} != "" ) {
                        echo '<div class="c-sections--description">' . ${'description' . $i} . '</div>';
                    }

                    if ( ${'content' . $i} != "" ) {
                        echo  ${'content' . $i};
                    }

                    echo '</div>';
                echo '</div>';
            endif;
        endfor;
        echo '</div>';

        echo '</div>';

        // WordPress core after_widget hook (always include )
        echo $after_widget;
    }
}


// register Biuro_Sections
add_action( 'widgets_init', function(){
    register_widget( 'Biuro_Sections' );
});

