import Awesomplete from './vendor/awesomplete';
import Swiper from './vendor/swiper';

(global => {
    const container = document.getElementById('cookie-warning');
    const btnAgree = document.getElementById('cookie-agree');
    const btnClose = document.getElementById('cookie-close');
    const agreed = (useLS()) ? localStorage.getItem('biuro-agree') : false;

    function useLS () {
        var mod = 'a';
        try {
            localStorage.setItem(mod, mod);
            localStorage.removeItem(mod);
            return true;
        } catch (e) {
            return false;
        }
    }

    if (!container || !btnAgree || !btnClose || agreed) {
        return;
    }

    container.style.display = 'block';

    btnAgree.addEventListener('click', () => {
        if (useLS()) {
            localStorage.setItem('biuro-agree', 'true');
        }
        container.style.display = 'none';
    });

    btnClose.addEventListener('click', () => {
        container.style.display = 'none';
    });
})(window);

if (module.hot) {
    module.hot.accept();
}

(global => {
    const node = document.getElementById('js-map--divisions');

    if (!node) {
        return;
    }

    fetch('/wp-json/api/v1/divisions?lang=' + node.dataset.lang)
        .then((t) => t.json())
        .then((data) => {
            initDivisionsMap(node, data);
        });
})(window);

(global => {
    const node = document.getElementById('js-map--regions');

    if (!node) {
        return;
    }

    initRegionsMap(node);
})(window);

const mapStyles = [
    {
        featureType: 'all',
        elementType: 'all',
        stylers: [
            {
                'saturation': -92
            },
            {
                'lightness': -8
            },
            {
                'hue': '#0000ff'
            }
        ]
    },
    {
        'featureType': 'water',
        elementType: 'all',
        'stylers': [
            {
                'saturation': -95
            },
            {
                'lightness': -25
            },
            {
                'hue': '#0000ff'
            }
        ]
    }
];

function setMarkers (map, positions) {
    var info;
    var bounds = new window.google.maps.LatLngBounds();

    map.mapTypes.set('biuro', new window.google.maps.StyledMapType(mapStyles, { name: 'Biuro' }));

    map.setMapTypeId('biuro');

    for (var i = 0; i < positions.length; i++) {
        const position = positions[i];
        const pos = new window.google.maps.LatLng(position.lat, position.lng);

        var marker = new window.google.maps.Marker({
            position: pos,
            map: map,
            icon: '/wp-content/themes/biuro/i/ico--map-pin.svg',
            title: position.title || ''
        });

        bounds.extend(pos);

        if (position.content) {
            marker['content'] = position.content;

            window.google.maps.event.addListener(marker, 'click', function () {
                if (info) {
                    info.close();
                }

                info = new window.google.maps.InfoWindow({
                    content: this.content
                });

                info.open(map, this);
            });
        }
    }

    map.fitBounds(bounds);
}

function initRegionsMap (node) {
    if (!window.google) {
        setTimeout(() => { initRegionsMap(node); }, 250);
        return;
    }

    const map = new window.google.maps.Map(node, {
        mapTypeIds: [window.google.maps.MapTypeId.ROADMAP, window.google.maps.MapTypeId.HYBRID, 'biuro']
    });

    window.google.maps.event.addListenerOnce(map, 'bounds_changed', function () {
        if (this.getZoom() > 15) {
            this.setZoom(14);
        }
    });

    const regions = [
        { title: 'Vilnius', lat: 54.687157, lng: 25.279652 },
        { title: 'Rīga', lat: 56.946285, lng: 24.105078 },
        { title: 'Tallinn', lat: 59.436962, lng: 24.753574 }
    ];

    setMarkers(map, regions);
}

function initDivisionsMap (node, data) {
    if (!window.google) {
        setTimeout(() => { initDivisionsMap(node, data); }, 250);
        return;
    }

    const map = new window.google.maps.Map(node, {
        mapTypeIds: [window.google.maps.MapTypeId.ROADMAP, window.google.maps.MapTypeId.HYBRID, 'biuro']
    });

    window.google.maps.event.addListenerOnce(map, 'bounds_changed', function () {
        if (this.getZoom() > 15) {
            this.setZoom(14);
        }
    });

    let divisions = [];

    const region = document.querySelector('.js-active-region');
    const ID = (region && region.dataset.id) ? region.dataset.id : '';

    if (data[ID]) {
        divisions = data[ID];
    } else {
        Object.keys(data).forEach((key) => {
            const division = data[key];
            if (key.substr(0, 4) === 'city') {
                divisions = divisions.concat(division);
            }
        });
    }

    setMarkers(map, divisions.filter((d) => { return d.lat && d.lng; }));
}

(global => {
    const city = document.getElementById('search-city');

    if (!city) {
        return;
    }

    const search = document.getElementById('search');
    const query = document.getElementById('search-query');

    const cityBox = new Awesomplete(city, {
        minChars: 0,
        sort: false
        // data: (item, input) => {
        //     console.error('----------');
        //     console.dir(item);
        //     console.dir(input);
        //     return { label: item.value, value: item.name };
        // },
        // replace: function(text) {
        //     console.error('text');
        //     console.dir(text);
        //     // var hidden = document.querySelector('[name="' + this.input.dataset.name + '"]');

        //     // this.input.value = text.label;

        //     // if (!hidden) {
        //     //     return;
        //     // }

        //     // hidden.value = text.value;

        //     // if (hidden.classList.contains('js-trigger-datalist')) {
        //     //     hidden.dispatchEvent(new Event('change', {
        //     //         'bubbles': true,
        //     //         'cancelable': true
        //     //     }));
        //     // }

        //     // hidden.dispatchEvent(event);
        // }
    // });
    });

    city.addEventListener('focus', () => {
        cityBox.evaluate();
    });

    const queryBox = new Awesomplete(query, {
        minChars: 0,
        sort: false
    });

    query.addEventListener('focus', () => {
        queryBox.evaluate();
    });

    if (search) {
        search.addEventListener('submit', (e) => {
            if (!city.value && !query.value) {
                city.focus();
                e.preventDefault();
            }
        }, false);
    }

})(window);

const swiper = new Swiper('.c-feedbacks--inner', {
    autoplay: {
        delay: 4000,
        disableOnInteraction: false
    },
    grabCursor: true,
    loop: true,
    pagination: {
        el: '.swiper-pagination',
        clickable: true
    }
});
