<?php
/**
 * Template Name: Search & Jobs page
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Biuro
 * @since 1.0
 * @version 1.0
 */

get_header(); ?>

    <div class="l-section <?php if ( is_front_page() ):  ?> l-section--front-page <?php elseif (get_page_template_slug() == 'sales-page.php'): ?> l-section--sales-page <?php endif; ?>">
        <div class="l-section--inner">
            <?php

                if ( is_front_page() || get_page_template_slug() == 'sales-page.php' ):
                    while ( have_posts() ) :
?>
                    <div class="c-heading <?php if ( is_front_page() ):  ?> c-heading--front-page <?php elseif (get_page_template_slug() == 'sales-page.php'): ?> c-heading--sales-page <?php endif; ?>">
<?php
                        the_post();
                        the_content();
?>
                    </div>
<?php
                    endwhile;
                endif;

                // if ( is_search() ):
                //     wp_parse_str( $query_string, $searchQuery );
                // endif;

            if (get_page_template_slug() != 'sales-page.php'):
                get_search_form();
            endif;
?>
        </div>
    </div>

    <div id="content">

    <div class="l-content l-content--heading">
<?php

        while ( have_posts() ) :
            the_post();
            the_content();
        endwhile;
 ?>
    </div>
    <div class="l-content">

        <aside class="l-aside">
<?php
            get_template_part( 'template-parts/layout/aside', 'job-list' );
?>
        </aside><!-- .l-aside -->



        <main id="main" class="l-main">

<?php
    global $query_string;

    $ID =  get_the_ID();
    $keys =  get_post_custom_keys();

    $where = 'valid.meta_value > "' . date('Y-m-d', strtotime('-1 days')) . '"';

    if ( is_search() ):

        wp_parse_str( $query_string, $searchQuery );

        if ( $searchQuery ) :

            if ( $searchQuery['city'] ) :
                $city = get_term_by( 'name', preg_replace('/[\+]/', ' ', $searchQuery['city']), 'city' );

                if ( $city ) :
                    $where = $where . ' AND city.term_id = ' . $city->term_id;
                endif;
            endif;

            if ( $searchQuery['s'] ) :

                $field = get_term_by( 'name', preg_replace('/[\+]/', ' ', $searchQuery['s']), 'field' );
                $type = get_term_by( 'name', preg_replace('/[\+]/', ' ', $searchQuery['s']), 'type' );

                if ( $field ) :
                    $where = $where . ' AND field.term_id = ' . $field->term_id;
                elseif ( $type ) :
                    $where = $where . ' AND type.term_id = ' . $type->term_id;
                else:
                    $where = $where . ' AND (t.post_title LIKE "%' . $searchQuery['s'] . '%" OR  t.post_content LIKE "%' . $searchQuery['s'] . '%")';
                endif;

            endif;
        endif;

        // $where = 'valid.meta_value > "' . date('Y-m-d', strtotime('-1 days')) . '" AND (t.post_title LIKE "%' . $searchQuery . '%" OR  t.post_content LIKE "%' . $searchQuery . '%")';

    elseif ($keys):
        foreach ( $keys as $key => $value ) :
            $val = trim($value);
            $taxonomy = substr($val, 20);

            if ( '_' == $val{0} || substr($val, 0, 20) != 'built_in_taxonomies_' || !$taxonomy):
                continue;
            endif;

            $res = get_post_custom_values( $val, $ID );

            if ( !$res ) :
                continue;
            endif;

            $term = $res[0];

            if ( !$term ) :
                continue;
            endif;

            $where = $where . ' AND ' .  $taxonomy . '.slug = "' . $term . '"';
        endforeach;
    endif;

    $params = array(
        'orderby' => 'date DESC',
        'where' => $where,
        'limit'   => 21
    );

    $jobs = pods( 'job', $params );

    if ( 0 < $jobs->total() ):

        get_template_part( 'template-parts/jobs/jobs', 'list' );

    else:

        get_template_part( 'template-parts/jobs/jobs', 'not-found' );

    endif;
?>

            </main><!-- .l-main -->
        </div><!-- .l-content -->

    </div><!-- #content -->

<?php get_footer();
